@@ -5,7 +5,7 @@ use Carp;
 use Text::CSV_XS;
 use Scalar::Util qw( reftype );
 use Cwd;
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 use Parse::Taxonomy::Auxiliary qw(
     path_check_fields
     components_check_fields
@@ -177,10 +177,13 @@ sub new {
 
     croak "Argument to 'new()' must be hashref"
         unless (ref($args) and reftype($args) eq 'HASH');
+    my $argscount = 0;
+    $argscount++ if $args->{file};
+    $argscount++ if $args->{components};
     croak "Argument to 'new()' must have either 'file' or 'components' element"
-        unless ($args->{file} or $args->{components});
+        if ($argscount == 0);
     croak "Argument to 'new()' must have either 'file' or 'components' element but not both"
-        if ($args->{file} and $args->{components});
+        if ($argscount == 2);
 
     $data->{id_col}         = $args->{id_col}
                                 ? delete $args->{id_col}
