@@ -6,7 +6,7 @@ use Text::CSV_XS;
 use Scalar::Util qw( reftype );
 use List::Util qw( max );
 use Cwd;
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 use Parse::Taxonomy::Auxiliary qw(
     path_check_fields
     components_check_fields
@@ -176,10 +176,13 @@ sub new {
 
     croak "Argument to 'new()' must be hashref"
         unless (ref($args) and reftype($args) eq 'HASH');
+    my $argscount = 0;
+    $argscount++ if $args->{file};
+    $argscount++ if $args->{components};
     croak "Argument to 'new()' must have either 'file' or 'components' element"
-        unless ($args->{file} or $args->{components});
+        if ($argscount == 0);
     croak "Argument to 'new()' must have either 'file' or 'components' element but not both"
-        if ($args->{file} and $args->{components});
+        if ($argscount == 2);
 
     if (exists $args->{path_col_idx}) {
         croak "Argument to 'path_col_idx' must be integer"
@@ -245,12 +248,12 @@ sub new {
     while (my ($k,$v) = each %{$args}) {
         $data->{$k} = $v;
     }
-    my %row_depths = ();
+    my %row_analysis = ();
     for my $el (@{$data->{data_records}}) {
         my $rowkey = $el->[$data->{path_col_idx}];
-        $row_depths{$rowkey} = split(/\Q$data->{path_col_sep}\E/, $rowkey);
+        $row_analysis{$rowkey} = split(/\Q$data->{path_col_sep}\E/, $rowkey);
     }
-    $data->{row_depths} = \%row_depths;
+    $data->{row_analysis} = \%row_analysis;
     return bless $data, $class;
 }
 
@@ -700,7 +703,7 @@ sub descendant_counts {
     for my $p (keys %{$hashified}) {
         $descendant_counts{$p} = 0;
         for my $q (
-            grep { $self->{row_depths}->{$_} > $self->{row_depths}->{$p} }
+            grep { $self->{row_analysis}->{$_} > $self->{row_analysis}->{$p} }
             keys %{$hashified}
         ) {
             $descendant_counts{$p}++ if $q =~ m/^\Q$p$self->{path_col_sep}\E/;
@@ -894,14 +897,20 @@ Transform a taxonomy-by-materialized-path into a taxonomy-by-adjacent-list.
     $adjacentified = $self->adjacentify();
 
     $adjacentified = $self->adjacentify( { serial => 500 } );
+    $adjacentified = $self->adjacentify( { floor  => 500 } );  # same as serial
 
 Optional single hash reference.
 
-At this time the only key supported for that
-hash is C<serial>, which defaults to C<0>.  C<serial> must be a non-negative
-integer and sets the "floor" above which new unique IDs will be assigned to
-the C<id> column.  Hence, if C<serial> is set to C<500>, the value assigned to
-the C<id> column of the first record to be processed will be C<501>.
+For that hashref, C<adjacentify()> supports the key C<serial>, which defaults
+to C<0>.  C<serial> must be a non-negative integer and sets the "floor" above
+which new unique IDs will be assigned to the C<id> column.  Hence, if
+C<serial> is set to C<500>, the value assigned to the C<id> column of the
+first record to be processed will be C<501>.
+
+Starting with version 0.19, C<floor> will serve as an alternative way of
+providing the same information to C<adjacentify()>.  If, however, by mistake
+you provide B<both> C<serial> and C<floor> elements in the hash, C<serial>
+will take precedence.
 
 =item * Return Value
 
@@ -926,11 +935,20 @@ the data structure returned by a method such as C<data_records()>.
 
 sub adjacentify {
     my ($self, $args) = @_;
+    my $serial = 0;
     if (defined $args) {
         croak "Argument to 'adjacentify()' must be hashref"
             unless (ref($args) and reftype($args) eq 'HASH');
+        for my $w ('serial', 'floor') {
+            if (exists $args->{$w}) {
+                croak "Element '$w' in argument to 'adjacentify()' must be integer"
+                    unless ($args->{$w} =~ m/^\d+$/);
+            }
+        }
+        $serial = $args->{serial} || $args->{floor} || 0;
     }
 
+
     my $fields = $self->fields();
     my $drpc = $self->data_records_path_components();
 
@@ -940,9 +958,8 @@ sub adjacentify {
         (0..$#{$fields});
 
     my @components_by_row =
-        map { my $f = $_->[$path_col_idx]; my $c = $#{$f}; [ @{$f}[1..$c] ] }  @{$drpc};
+        map { my $f = $_->[$path_col_idx]; my $c = $#{$f}; [ @{$f}[1..$c] ] } @{$drpc};
     my $max_components = max( map { scalar(@{$_}) } @components_by_row);
-    my $serial = $args->{serial} || 0;
     my @adjacentified = ();
     my %paths_to_id;
     for my $depth (1..$max_components) {
